@@ -1,11 +1,8 @@
 package Catalyst::Plugin::MemoryUsage;
-BEGIN {
-  $Catalyst::Plugin::MemoryUsage::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Catalyst::Plugin::MemoryUsage::VERSION = '0.4.0';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Profile memory usage of requests
+$Catalyst::Plugin::MemoryUsage::VERSION = '0.4.1';
+use 5.10.0;
 
 use strict;
 use warnings;
@@ -25,43 +22,34 @@ our @SUPPORTED_OSES = qw/ Linux NetBSD /;
 
 our $os_not_supported = Devel::CheckOS::os_isnt( @SUPPORTED_OSES );
 
-if ( $os_not_supported ) {
-    warn "OS not supported by Catalyst::Plugin::MemoryUsage\n",
-         "\tStats will not be collected\n";
-}
+warn "OS not supported by Catalyst::Plugin::MemoryUsage\n",
+    "\tStats will not be collected\n" 
+        if $os_not_supported;
 
 
 has memory_usage => (
-    is => 'rw',
+    is      => 'ro',
+    lazy    => 1,
     default => sub { Memory::Usage->new },
+    clearer => 'reset_memory_usage',
 );
 
 our $_memory_usage_report;
 our $_memory_usage_record_actions;
 
-
 after setup_finalize => sub {
     my $c = shift;
 
     my %config = %{ $c->config->{'Plugin::MemoryUsage'} || {} };
 
-    $_memory_usage_report = 
-        exists $config{report} ? $config{report} : $c->debug;
+    $_memory_usage_report = $config{report} // $c->debug;
 
-    $_memory_usage_record_actions = 
-        exists $config{action_milestones} 
-            ? $config{action_milestones} : $c->debug;
+    $_memory_usage_record_actions = $config{action_milestones} // $c->debug;
 };
 
 
 
 
-sub reset_memory_usage {
-    my $self = shift;
-
-    $self->memory_usage( Memory::Usage->new );
-}
-
 sub memory_usage_report {
     my $self = shift;
 
@@ -70,16 +58,9 @@ sub memory_usage_report {
 
     my $table = Text::SimpleTable->new( 
         [$title_width, ''],
-        [4, 'vsz'],
-        [4, 'delta'],
-        [4, 'rss'],
-        [4, 'delta'],
-        [4, 'shared'],
-        [4, 'delta'],
-        [4, 'code'],
-        [4, 'delta'],
-        [4, 'data'],
-        [4, 'delta'],
+        map { [ 4, $_ ] } 
+        map { ( $_, 'delta' ) }
+            qw/ vsz rss  shared code data /
     );
 
     my @previous;
@@ -100,38 +81,38 @@ sub memory_usage_report {
 
 unless ( $os_not_supported ) {
 
-after execute => sub {
-    return unless $_memory_usage_record_actions;
+    after execute => sub {
+        return unless $_memory_usage_record_actions;
 
-    my $c = shift;
-    $c->memory_usage->record( "after " . join " : ", @_ );
-};
+        my $c = shift;
+        $c->memory_usage->record( "after " . join " : ", @_ );
+    };
 
-around prepare => sub {
-    my $orig = shift;
-    my $self = shift;
+    around prepare => sub {
+        my $orig = shift;
+        my $self = shift;
 
-    my $c = $self->$orig(@_);
+        my $c = $self->$orig(@_);
 
-    $c->memory_usage->record('preparing for the request') 
-        if $_memory_usage_record_actions;
+        $c->memory_usage->record('preparing for the request') 
+            if $_memory_usage_record_actions;
 
-    return $c;
-};
+        return $c;
+    };
 
-after finalize => sub {
-    return unless $_memory_usage_report;
+    after finalize => sub {
+        return unless $_memory_usage_report;
 
-    my $c = shift;
-    $c->log->debug(
-        sprintf(qq{[%s] memory usage of request "%s" from "%s"\n},
-            [split m{::}, __PACKAGE__]->[-1],
-            $c->req->uri,
-            $c->req->address,
-        ),
-        $c->memory_usage_report
-    );
-};
+        my $c = shift;
+        $c->log->debug(
+            sprintf(qq{[%s] memory usage of request "%s" from "%s"\n},
+                [split m{::}, __PACKAGE__]->[-1],
+                $c->req->uri,
+                $c->req->address,
+            ),
+            $c->memory_usage_report
+        );
+    };
 
 }
 
@@ -141,13 +122,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Catalyst::Plugin::MemoryUsage - Profile memory usage of requests
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -155,9 +138,7 @@ In YourApp.pm:
 
     package YourApp;
 
-    use Catalyst qw/
-        MemoryUsage
-    /;
+    use Catalyst qw/ MemoryUsage /;
 
 In a Controller class:
 
@@ -255,11 +236,11 @@ L<Memory::Usage>
 
 =head1 AUTHOR
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Yanick Champoux.
+This software is copyright (c) 2018, 2012, 2011, 2010 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
